Class: Google::Apis::AdsenseplatformV1alpha::AdSensePlatformService

Inherits:
Core::BaseService
  • Object
show all
Defined in:
lib/google/apis/adsenseplatform_v1alpha/service.rb

Overview

AdSense Platform API

Examples:

require 'google/apis/adsenseplatform_v1alpha'

Adsenseplatform = Google::Apis::AdsenseplatformV1alpha # Alias the module
service = Adsenseplatform::AdSensePlatformService.new

See Also:

Constant Summary collapse

DEFAULT_ENDPOINT_TEMPLATE =
"https://adsenseplatform.$UNIVERSE_DOMAIN$/"

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeAdSensePlatformService

Returns a new instance of AdSensePlatformService.



47
48
49
50
51
52
# File 'lib/google/apis/adsenseplatform_v1alpha/service.rb', line 47

def initialize
  super(DEFAULT_ENDPOINT_TEMPLATE, '',
        client_name: 'google-apis-adsenseplatform_v1alpha',
        client_version: Google::Apis::AdsenseplatformV1alpha::GEM_VERSION)
  @batch_path = 'batch'
end

Instance Attribute Details

#keyString

Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.

Returns:

  • (String)

    API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.



40
41
42
# File 'lib/google/apis/adsenseplatform_v1alpha/service.rb', line 40

def key
  @key
end

#quota_userString

Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

Returns:

  • (String)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.



45
46
47
# File 'lib/google/apis/adsenseplatform_v1alpha/service.rb', line 45

def quota_user
  @quota_user
end

Instance Method Details

#close_account(name, close_account_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AdsenseplatformV1alpha::CloseAccountResponse

Closes a sub-account.

Parameters:

  • name (String)

    Required. Account to close. Format: platforms/platform/accounts/account_id

  • close_account_request_object (Google::Apis::AdsenseplatformV1alpha::CloseAccountRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



370
371
372
373
374
375
376
377
378
379
380
# File 'lib/google/apis/adsenseplatform_v1alpha/service.rb', line 370

def (name,  = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1alpha/{+name}:close', options)
  command.request_representation = Google::Apis::AdsenseplatformV1alpha::CloseAccountRequest::Representation
  command.request_object = 
  command.response_representation = Google::Apis::AdsenseplatformV1alpha::CloseAccountResponse::Representation
  command.response_class = Google::Apis::AdsenseplatformV1alpha::CloseAccountResponse
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#create_platform_account(parent, account_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AdsenseplatformV1alpha::Account

Creates a sub-account.

Parameters:

  • parent (String)

    Required. Platform to create an account for. Format: platforms/platform

  • account_object (Google::Apis::AdsenseplatformV1alpha::Account) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



403
404
405
406
407
408
409
410
411
412
413
# File 'lib/google/apis/adsenseplatform_v1alpha/service.rb', line 403

def (parent,  = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1alpha/{+parent}/accounts', options)
  command.request_representation = Google::Apis::AdsenseplatformV1alpha::Account::Representation
  command.request_object = 
  command.response_representation = Google::Apis::AdsenseplatformV1alpha::Account::Representation
  command.response_class = Google::Apis::AdsenseplatformV1alpha::Account
  command.params['parent'] = parent unless parent.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#create_platform_account_event(parent, event_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AdsenseplatformV1alpha::Event

Creates an account event.

Parameters:

  • parent (String)

    Required. Account to log events about. Format: platforms/platform/accounts/ account

  • event_object (Google::Apis::AdsenseplatformV1alpha::Event) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



541
542
543
544
545
546
547
548
549
550
551
# File 'lib/google/apis/adsenseplatform_v1alpha/service.rb', line 541

def (parent, event_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1alpha/{+parent}/events', options)
  command.request_representation = Google::Apis::AdsenseplatformV1alpha::Event::Representation
  command.request_object = event_object
  command.response_representation = Google::Apis::AdsenseplatformV1alpha::Event::Representation
  command.response_class = Google::Apis::AdsenseplatformV1alpha::Event
  command.params['parent'] = parent unless parent.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#create_platform_account_site(parent, site_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AdsenseplatformV1alpha::Site

Creates a site for a specified account.

Parameters:

  • parent (String)

    Required. Account to create site. Format: platforms/platform/accounts/ account_id

  • site_object (Google::Apis::AdsenseplatformV1alpha::Site) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



575
576
577
578
579
580
581
582
583
584
585
# File 'lib/google/apis/adsenseplatform_v1alpha/service.rb', line 575

def (parent, site_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1alpha/{+parent}/sites', options)
  command.request_representation = Google::Apis::AdsenseplatformV1alpha::Site::Representation
  command.request_object = site_object
  command.response_representation = Google::Apis::AdsenseplatformV1alpha::Site::Representation
  command.response_class = Google::Apis::AdsenseplatformV1alpha::Site
  command.params['parent'] = parent unless parent.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#delete_platform_account_site(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AdsenseplatformV1alpha::Empty

Deletes a site from a specified account.

Parameters:

  • name (String)

    Required. The name of the site to delete. Format: platforms/platform/ accounts/account/sites/site

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



608
609
610
611
612
613
614
615
616
# File 'lib/google/apis/adsenseplatform_v1alpha/service.rb', line 608

def (name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:delete, 'v1alpha/{+name}', options)
  command.response_representation = Google::Apis::AdsenseplatformV1alpha::Empty::Representation
  command.response_class = Google::Apis::AdsenseplatformV1alpha::Empty
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_account_platform(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AdsenseplatformV1alpha::Platform

Gets a platform.

Parameters:

  • name (String)

    Required. The name of the platform to retrieve. Format: accounts/account/ platforms/platform

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



75
76
77
78
79
80
81
82
83
# File 'lib/google/apis/adsenseplatform_v1alpha/service.rb', line 75

def (name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1alpha/{+name}', options)
  command.response_representation = Google::Apis::AdsenseplatformV1alpha::Platform::Representation
  command.response_class = Google::Apis::AdsenseplatformV1alpha::Platform
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_account_platform_child_account_site(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AdsenseplatformV1alpha::PlatformChildSite

Gets a Platform Child Site for a specified Platform Child Account and site.

Parameters:

  • name (String)

    Required. The name of the platform child site to retrieve. Format: accounts/ account/platforms/platform/childAccounts/child_account/sites/ platform_child_site

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



147
148
149
150
151
152
153
154
155
# File 'lib/google/apis/adsenseplatform_v1alpha/service.rb', line 147

def (name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1alpha/{+name}', options)
  command.response_representation = Google::Apis::AdsenseplatformV1alpha::PlatformChildSite::Representation
  command.response_class = Google::Apis::AdsenseplatformV1alpha::PlatformChildSite
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_account_platform_group(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AdsenseplatformV1alpha::PlatformGroup

Gets a Platform Group for a specified Platform and group.

Parameters:

  • name (String)

    Required. The name of the platform group to retrieve. Format: accounts/ account/platforms/platform/groups/group

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



259
260
261
262
263
264
265
266
267
# File 'lib/google/apis/adsenseplatform_v1alpha/service.rb', line 259

def (name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1alpha/{+name}', options)
  command.response_representation = Google::Apis::AdsenseplatformV1alpha::PlatformGroup::Representation
  command.response_class = Google::Apis::AdsenseplatformV1alpha::PlatformGroup
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_platform_account(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AdsenseplatformV1alpha::Account

Gets information about the selected sub-account.

Parameters:

  • name (String)

    Required. Account to get information about. Format: platforms/platform/ accounts/account_id

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



436
437
438
439
440
441
442
443
444
# File 'lib/google/apis/adsenseplatform_v1alpha/service.rb', line 436

def (name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1alpha/{+name}', options)
  command.response_representation = Google::Apis::AdsenseplatformV1alpha::Account::Representation
  command.response_class = Google::Apis::AdsenseplatformV1alpha::Account
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_platform_account_site(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AdsenseplatformV1alpha::Site

Gets a site from a specified sub-account.

Parameters:

  • name (String)

    Required. The name of the site to retrieve. Format: platforms/platform/ accounts/account/sites/site

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



639
640
641
642
643
644
645
646
647
# File 'lib/google/apis/adsenseplatform_v1alpha/service.rb', line 639

def (name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1alpha/{+name}', options)
  command.response_representation = Google::Apis::AdsenseplatformV1alpha::Site::Representation
  command.response_class = Google::Apis::AdsenseplatformV1alpha::Site
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_account_platform_child_account_sites(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AdsenseplatformV1alpha::ListPlatformChildSitesResponse

Lists Platform Child Sites for a specified Platform Child Account.

Parameters:

  • parent (String)

    Required. The name of the child account under the given platform which owns the platform child sites. Format: accounts/account/platforms/platform/ childAccounts/child_account

  • page_size (Fixnum) (defaults to: nil)

    Optional. The maximum number of children to include in the response, used for paging. If unspecified, at most 10000 platforms will be returned. The maximum value is 10000; values above 10000 will be coerced to 10000.

  • page_token (String) (defaults to: nil)

    Optional. A page token, received from a previous ListPlatformChildSites call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to ListPlatformChildSites must match the call that provided the page token.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



188
189
190
191
192
193
194
195
196
197
198
# File 'lib/google/apis/adsenseplatform_v1alpha/service.rb', line 188

def (parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1alpha/{+parent}/sites', options)
  command.response_representation = Google::Apis::AdsenseplatformV1alpha::ListPlatformChildSitesResponse::Representation
  command.response_class = Google::Apis::AdsenseplatformV1alpha::ListPlatformChildSitesResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_account_platform_groups(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AdsenseplatformV1alpha::ListPlatformGroupsResponse

Lists Platform Groups for a specified Platform.

Parameters:

  • parent (String)

    Required. The name of the platform to retrieve. Format: accounts/account/ platforms/platform

  • page_size (Fixnum) (defaults to: nil)

    Optional. The maximum number of groups to include in the response, used for paging. If unspecified, at most 10000 groups will be returned. The maximum value is 10000; values above 10000 will be coerced to 10000.

  • page_token (String) (defaults to: nil)

    Optional. A page token, received from a previous ListPlatformGroups call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to ListPlatformGroups must match the call that provided the page token.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



299
300
301
302
303
304
305
306
307
308
309
# File 'lib/google/apis/adsenseplatform_v1alpha/service.rb', line 299

def (parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1alpha/{+parent}/groups', options)
  command.response_representation = Google::Apis::AdsenseplatformV1alpha::ListPlatformGroupsResponse::Representation
  command.response_class = Google::Apis::AdsenseplatformV1alpha::ListPlatformGroupsResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_account_platforms(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AdsenseplatformV1alpha::ListPlatformsResponse

Lists platforms for a specified account.

Parameters:

  • parent (String)

    Required. The account which owns the platforms. Format: accounts/account

  • page_size (Fixnum) (defaults to: nil)

    Optional. The maximum number of platforms to include in the response, used for paging. If unspecified, at most 10000 platforms will be returned. The maximum value is 10000; values above 10000 will be coerced to 10000.

  • page_token (String) (defaults to: nil)

    Optional. A page token, received from a previous ListPlatforms call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to ListPlatforms must match the call that provided the page token.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



113
114
115
116
117
118
119
120
121
122
123
# File 'lib/google/apis/adsenseplatform_v1alpha/service.rb', line 113

def (parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1alpha/{+parent}/platforms', options)
  command.response_representation = Google::Apis::AdsenseplatformV1alpha::ListPlatformsResponse::Representation
  command.response_class = Google::Apis::AdsenseplatformV1alpha::ListPlatformsResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_platform_account_sites(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AdsenseplatformV1alpha::ListSitesResponse

Lists sites for a specific account.

Parameters:

  • parent (String)

    Required. The account which owns the sites. Format: platforms/platform/ accounts/account

  • page_size (Fixnum) (defaults to: nil)

    The maximum number of sites to include in the response, used for paging. If unspecified, at most 10000 sites will be returned. The maximum value is 10000; values above 10000 will be coerced to 10000.

  • page_token (String) (defaults to: nil)

    A page token, received from a previous ListSites call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to ListSites must match the call that provided the page token.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



678
679
680
681
682
683
684
685
686
687
688
# File 'lib/google/apis/adsenseplatform_v1alpha/service.rb', line 678

def (parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1alpha/{+parent}/sites', options)
  command.response_representation = Google::Apis::AdsenseplatformV1alpha::ListSitesResponse::Representation
  command.response_class = Google::Apis::AdsenseplatformV1alpha::ListSitesResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_platform_accounts(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AdsenseplatformV1alpha::ListAccountsResponse

Lists a partial view of sub-accounts for a specific parent account.

Parameters:

  • parent (String)

    Required. Platform who parents the accounts. Format: platforms/platform

  • page_size (Fixnum) (defaults to: nil)

    Optional. The maximum number of accounts to include in the response, used for paging. If unspecified, at most 10000 accounts will be returned. The maximum value is 10000; values above 10000 will be coerced to 10000.

  • page_token (String) (defaults to: nil)

    Optional. A page token, received from a previous ListAccounts call. Provide this to retrieve the subsequent page.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



473
474
475
476
477
478
479
480
481
482
483
# File 'lib/google/apis/adsenseplatform_v1alpha/service.rb', line 473

def list_platform_accounts(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1alpha/{+parent}/accounts', options)
  command.response_representation = Google::Apis::AdsenseplatformV1alpha::ListAccountsResponse::Representation
  command.response_class = Google::Apis::AdsenseplatformV1alpha::ListAccountsResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#lookup_platform_account(parent, creation_request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AdsenseplatformV1alpha::LookupAccountResponse

Looks up information about a sub-account for a specified creation_request_id. If no account exists for the given creation_request_id, returns 404.

Parameters:

  • parent (String)

    Required. Platform who parents the account. Format: platforms/platform

  • creation_request_id (String) (defaults to: nil)

    Optional. The creation_request_id provided when calling createAccount.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



508
509
510
511
512
513
514
515
516
517
# File 'lib/google/apis/adsenseplatform_v1alpha/service.rb', line 508

def (parent, creation_request_id: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1alpha/{+parent}/accounts:lookup', options)
  command.response_representation = Google::Apis::AdsenseplatformV1alpha::LookupAccountResponse::Representation
  command.response_class = Google::Apis::AdsenseplatformV1alpha::LookupAccountResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['creationRequestId'] = creation_request_id unless creation_request_id.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#patch_account_platform_child_account_site(name, platform_child_site_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AdsenseplatformV1alpha::PlatformChildSite

Update a Platform Child Site.

Parameters:

  • name (String)

    Identifier. Format: accounts/account/platforms/platform/childAccounts/ child_account/sites/platform_child_site

  • platform_child_site_object (Google::Apis::AdsenseplatformV1alpha::PlatformChildSite) (defaults to: nil)
  • update_mask (String) (defaults to: nil)

    Optional. The list of fields to update - currently only supports updating the platform_group field.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/google/apis/adsenseplatform_v1alpha/service.rb', line 225

def (name, platform_child_site_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:patch, 'v1alpha/{+name}', options)
  command.request_representation = Google::Apis::AdsenseplatformV1alpha::PlatformChildSite::Representation
  command.request_object = platform_child_site_object
  command.response_representation = Google::Apis::AdsenseplatformV1alpha::PlatformChildSite::Representation
  command.response_class = Google::Apis::AdsenseplatformV1alpha::PlatformChildSite
  command.params['name'] = name unless name.nil?
  command.query['updateMask'] = update_mask unless update_mask.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#patch_account_platform_group(name, platform_group_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AdsenseplatformV1alpha::PlatformGroup

Update a Platform Group.

Parameters:

  • name (String)

    Identifier. Format: accounts/account/platforms/platform/groups/ platform_group

  • platform_group_object (Google::Apis::AdsenseplatformV1alpha::PlatformGroup) (defaults to: nil)
  • update_mask (String) (defaults to: nil)

    Optional. The list of fields to update - currently only supports updating the description field.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



336
337
338
339
340
341
342
343
344
345
346
347
# File 'lib/google/apis/adsenseplatform_v1alpha/service.rb', line 336

def (name, platform_group_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:patch, 'v1alpha/{+name}', options)
  command.request_representation = Google::Apis::AdsenseplatformV1alpha::PlatformGroup::Representation
  command.request_object = platform_group_object
  command.response_representation = Google::Apis::AdsenseplatformV1alpha::PlatformGroup::Representation
  command.response_class = Google::Apis::AdsenseplatformV1alpha::PlatformGroup
  command.params['name'] = name unless name.nil?
  command.query['updateMask'] = update_mask unless update_mask.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#request_platform_account_site_review(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AdsenseplatformV1alpha::RequestSiteReviewResponse

Requests the review of a site. The site should be in REQUIRES_REVIEW or NEEDS_ATTENTION state. Note: Make sure you place an ad tag on your site before requesting a review.

Parameters:

  • name (String)

    Required. The name of the site to submit for review. Format: platforms/ platform/accounts/account/sites/site

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



714
715
716
717
718
719
720
721
722
# File 'lib/google/apis/adsenseplatform_v1alpha/service.rb', line 714

def (name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1alpha/{+name}:requestReview', options)
  command.response_representation = Google::Apis::AdsenseplatformV1alpha::RequestSiteReviewResponse::Representation
  command.response_class = Google::Apis::AdsenseplatformV1alpha::RequestSiteReviewResponse
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end