Class: Google::Apis::AdsenseplatformV1alpha::ListPlatformChildSitesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/adsenseplatform_v1alpha/classes.rb,
lib/google/apis/adsenseplatform_v1alpha/representations.rb,
lib/google/apis/adsenseplatform_v1alpha/representations.rb

Overview

Response definition for the list platform child sites rpc.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListPlatformChildSitesResponse

Returns a new instance of ListPlatformChildSitesResponse.



363
364
365
# File 'lib/google/apis/adsenseplatform_v1alpha/classes.rb', line 363

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Continuation token used to page through platforms. To retrieve the next page of the results, set the next request's "page_token" value to this. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


356
357
358
# File 'lib/google/apis/adsenseplatform_v1alpha/classes.rb', line 356

def next_page_token
  @next_page_token
end

#platform_child_sitesArray<Google::Apis::AdsenseplatformV1alpha::PlatformChildSite>

The platform child sites returned in this list response. Corresponds to the JSON property platformChildSites



361
362
363
# File 'lib/google/apis/adsenseplatform_v1alpha/classes.rb', line 361

def platform_child_sites
  @platform_child_sites
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



368
369
370
371
# File 'lib/google/apis/adsenseplatform_v1alpha/classes.rb', line 368

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @platform_child_sites = args[:platform_child_sites] if args.key?(:platform_child_sites)
end