Class: Google::Apis::AdsenseplatformV1alpha::PlatformChildSite
- Inherits:
-
Object
- Object
- Google::Apis::AdsenseplatformV1alpha::PlatformChildSite
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/adsenseplatform_v1alpha/classes.rb,
lib/google/apis/adsenseplatform_v1alpha/representations.rb,
lib/google/apis/adsenseplatform_v1alpha/representations.rb
Overview
Representation of a Transparent Platform Child Site.
Instance Attribute Summary collapse
-
#domain ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#platform_group ⇒ String
Resource name of the Platform Group of the Platform Child Site.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PlatformChildSite
constructor
A new instance of PlatformChildSite.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PlatformChildSite
Returns a new instance of PlatformChildSite.
524 525 526 |
# File 'lib/google/apis/adsenseplatform_v1alpha/classes.rb', line 524 def initialize(**args) update!(**args) end |
Instance Attribute Details
#domain ⇒ String
Output only. Domain URL of the Platform Child Site. Part of the
PlatformChildSite name.
Corresponds to the JSON property domain
511 512 513 |
# File 'lib/google/apis/adsenseplatform_v1alpha/classes.rb', line 511 def domain @domain end |
#name ⇒ String
Identifier. Format: accounts/account/platforms/platform/childAccounts/
child_account/sites/platform_child_site
Corresponds to the JSON property name
517 518 519 |
# File 'lib/google/apis/adsenseplatform_v1alpha/classes.rb', line 517 def name @name end |
#platform_group ⇒ String
Resource name of the Platform Group of the Platform Child Site.
Corresponds to the JSON property platformGroup
522 523 524 |
# File 'lib/google/apis/adsenseplatform_v1alpha/classes.rb', line 522 def platform_group @platform_group end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
529 530 531 532 533 |
# File 'lib/google/apis/adsenseplatform_v1alpha/classes.rb', line 529 def update!(**args) @domain = args[:domain] if args.key?(:domain) @name = args[:name] if args.key?(:name) @platform_group = args[:platform_group] if args.key?(:platform_group) end |