Class: Google::Apis::AdsenseplatformV1alpha::PlatformGroup
- Inherits:
-
Object
- Object
- Google::Apis::AdsenseplatformV1alpha::PlatformGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/adsenseplatform_v1alpha/classes.rb,
lib/google/apis/adsenseplatform_v1alpha/representations.rb,
lib/google/apis/adsenseplatform_v1alpha/representations.rb
Overview
Representation of a Transparent Platform Group.
Instance Attribute Summary collapse
-
#description ⇒ String
Required.
-
#name ⇒ String
Identifier.
-
#revshare_millipercent ⇒ Google::Apis::AdsenseplatformV1alpha::Decimal
A representation of a decimal value, such as 2.5.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PlatformGroup
constructor
A new instance of PlatformGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PlatformGroup
Returns a new instance of PlatformGroup.
559 560 561 |
# File 'lib/google/apis/adsenseplatform_v1alpha/classes.rb', line 559 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Required. Description of the PlatformGroup.
Corresponds to the JSON property description
543 544 545 |
# File 'lib/google/apis/adsenseplatform_v1alpha/classes.rb', line 543 def description @description end |
#name ⇒ String
Identifier. Format: accounts/account/platforms/platform/groups/
platform_group
Corresponds to the JSON property name
549 550 551 |
# File 'lib/google/apis/adsenseplatform_v1alpha/classes.rb', line 549 def name @name end |
#revshare_millipercent ⇒ Google::Apis::AdsenseplatformV1alpha::Decimal
A representation of a decimal value, such as 2.5. Clients may convert values
into language-native decimal formats, such as Java's BigDecimal or
Python's decimal.Decimal.
Corresponds to the JSON property revshareMillipercent
557 558 559 |
# File 'lib/google/apis/adsenseplatform_v1alpha/classes.rb', line 557 def revshare_millipercent @revshare_millipercent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
564 565 566 567 568 |
# File 'lib/google/apis/adsenseplatform_v1alpha/classes.rb', line 564 def update!(**args) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) @revshare_millipercent = args[:revshare_millipercent] if args.key?(:revshare_millipercent) end |